use clap::{Arg, Command};
use rookie::enums::Cookie;

fn main() {
    let matches = Command::new("cookiex")
        .version("1.0")
        .author("JMARyA <jmarya@hydrar.de>")
        .about("Extract cookies from your browser session")
        .arg(
            Arg::new("browser")
                .short('b')
                .long("browser")
                .value_name("BROWSER")
                .help("The browser to extract cookies from [firefox / chromium / chrome / edge]"),
        )
        .arg(
            Arg::new("domains")
                .help("List of domains to process")
                .value_name("DOMAINS"),
        )
        .get_matches();

    let browser: Option<&String> = matches.get_one("browser");
    let domains: Option<&String> = matches.get_one::<String>("domains");
    let domains = domains.map(|x| {
        x.split(',')
            .map(std::string::ToString::to_string)
            .collect::<Vec<_>>()
    });

    let cookies = match browser
        .map_or("firefox".to_string(), |x| x.to_lowercase())
        .as_str()
    {
        "firefox" => rookie::firefox(domains).unwrap(),
        "chromium" => rookie::chromium(domains).unwrap(),
        "chrome" => rookie::chrome(domains).unwrap(),
        "edge" => rookie::edge(domains).unwrap(),
        _ => {
            std::process::exit(1);
        }
    };

    for cookie in cookies {
        let line = cookie.netscape();
        println!("{line}");
    }
}

pub trait NetscapeCookie {
    fn netscape(&self) -> String;
}

impl NetscapeCookie for Cookie {
    fn netscape(&self) -> String {
        format!(
            "{}\t{}\t{}\t{}\t{}\t{}\t{}",
            self.domain,
            self.http_only.to_string().to_uppercase(),
            self.path,
            self.secure.to_string().to_uppercase(),
            self.expires.unwrap_or(u64::MAX),
            self.name,
            self.value
        )
    }
}
